==> enterprisemodules-wls_config-3.3.15.tar.gz: enterprisemodules-wls_config-3.3.15/lib/puppet/type/wls_jms_template.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_jms_template) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a template in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_template { 'jmsClusterModule:Template-0':
          ensure          => 'present',
          redeliverydelay => '-1',
          redeliverylimit => '-1',
        }

    In this example you are managing a JMS template in the default domain. When you want to
    manage a JMS template in a specific domain, you can use:

        wls_jms_template { 'my_domain/jmsClusterModule:Template-0':
          ensure          => 'present',
          redeliverydelay => '-1',
          redeliverylimit => '-1',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/Templates')
    bean_type('Template')

    ensurable
    parameter :template_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :redeliverydelay
    property :redeliverylimit
    extraproperties do
      property :thresholds_bytes_high
      property :thresholds_messages_high
      property :thresholds_messages_low
      property :thresholds_template_bean
      property :delivery_error_destination
      property :delivery_expiration_logging_policy
      property :delivery_expiration_policy
      property :delivery_redelivery_limit
      property :delivery_template_bean
      property :log_message_logging_enabled
      property :log_message_logging_format
      property :log_template_bean
      property :override_delivery_mode
      property :override_priority
      property :override_redelivery_delay
      property :override_template_bean
      property :override_time_to_deliver
      property :override_time_to_live
      property :thresholds_bytes_low
      property :attach_sender
      property :consumption_paused_at_startup
      property :default_unit_of_order
      property :destination_keys
      property :incomplete_work_expiration_time
      property :insertion_paused_at_startup
      property :maximum_message_size
      property :notes
      property :production_paused_at_startup
      property :quota
      property :saf_export_policy
      property :messaging_performance_preference
      property :unit_of_work_handling_policy
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :template_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.11.1.tar.gz: enterprisemodules-wls_config-3.11.1/lib/puppet/type/wls_jms_template.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_template) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a template in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_template { 'jmsClusterModule:Template-0':
          ensure          => 'present',
          redeliverydelay => '-1',
          redeliverylimit => '-1',
        }

    In this example you are managing a JMS template in the default domain. When you want to
    manage a JMS template in a specific domain, you can use:

        wls_jms_template { 'my_domain/jmsClusterModule:Template-0':
          ensure          => 'present',
          redeliverydelay => '-1',
          redeliverylimit => '-1',
        }

    DESC

    bean_path('/JMSSystemResources/%<jmsmodule>s/JMSResource/%<jmsmodule>s/Templates')
    bean_type('Template')

    ensurable
    parameter :template_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :redeliverydelay
    property :redeliverylimit
    extraproperties do
      property :thresholds_bytes_high
      property :thresholds_messages_high
      property :thresholds_messages_low
      property :thresholds_template_bean
      property :delivery_error_destination
      property :delivery_expiration_logging_policy
      property :delivery_expiration_policy
      property :delivery_redelivery_limit
      property :delivery_template_bean
      property :log_message_logging_enabled
      property :log_message_logging_format
      property :log_template_bean
      property :override_delivery_mode
      property :override_priority
      property :override_redelivery_delay
      property :override_template_bean
      property :override_time_to_deliver
      property :override_time_to_live
      property :thresholds_bytes_low
      property :attach_sender
      property :consumption_paused_at_startup
      property :default_unit_of_order
      property :destination_keys
      property :incomplete_work_expiration_time
      property :insertion_paused_at_startup
      property :maximum_message_size
      property :notes
      property :production_paused_at_startup
      property :quota
      property :saf_export_policy
      property :messaging_performance_preference
      property :unit_of_work_handling_policy
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :template_name) do
      /(.+):(.+)/
    end
  end
end
